==> haskell-ghc-exactprint-1.6.1-92-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-exactprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-exactprint
version:              1.6.1
visibility:           public
id:                   ghc-exactprint-1.6.1-LUtyLwJZqT5N9UlkCeQ7A
key:                  ghc-exactprint-1.6.1-LUtyLwJZqT5N9UlkCeQ7A
license:              BSD-3-Clause
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman, Matthew Pickering
synopsis:             ExactPrint for GHC
description:
    Using the API Annotations available from GHC 9.2.1, this
    library provides a means to round trip any code that can
    be compiled by GHC, currently excluding lhs files.

    Note: requires GHC 9.4.*. For earlier GHC
    versions see lower version numbers.

category:             Development
abi:                  282dd5d08ed2847e71480fa528bef7c4
exposed:              True
exposed-modules:
    Language.Haskell.GHC.ExactPrint
    Language.Haskell.GHC.ExactPrint.Dump
    Language.Haskell.GHC.ExactPrint.ExactPrint
    Language.Haskell.GHC.ExactPrint.Lookup
    Language.Haskell.GHC.ExactPrint.Orphans
    Language.Haskell.GHC.ExactPrint.Parsers
    Language.Haskell.GHC.ExactPrint.Preprocess
    Language.Haskell.GHC.ExactPrint.Transform
    Language.Haskell.GHC.ExactPrint.Types
    Language.Haskell.GHC.ExactPrint.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghc-exactprint-1.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghc-exactprint-1.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghc-exactprint-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-exactprint
hs-libraries:         HSghc-exactprint-1.6.1-LUtyLwJZqT5N9UlkCeQ7A
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd directory-1.3.7.1
    filepath-1.4.2.2 free-5.2-8n63L5XNWv09r5UXg2kWUU ghc-9.4.8
    ghc-boot-9.4.8 mtl-2.2.2
    ordered-containers-0.2.4-8yJuKa67lBVH8gmwTc8hSK
    syb-0.7.3-7hkxsEejTxP3yJx3PgFbmA

haddock-interfaces:
    /usr/share/doc/haskell-ghc-exactprint/html/ghc-exactprint.haddock

haddock-html:         /usr/share/doc/haskell-ghc-exactprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-exactprint-1.6.1-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-exactprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-exactprint
version:              1.6.1
visibility:           public
id:                   ghc-exactprint-1.6.1-71NAdlzl5fm9QnnWAHgUqY
key:                  ghc-exactprint-1.6.1-71NAdlzl5fm9QnnWAHgUqY
license:              BSD-3-Clause
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman, Matthew Pickering
synopsis:             ExactPrint for GHC
description:
    Using the API Annotations available from GHC 9.2.1, this
    library provides a means to round trip any code that can
    be compiled by GHC, currently excluding lhs files.

    Note: requires GHC 9.4.*. For earlier GHC
    versions see lower version numbers.

category:             Development
abi:                  6d63f471a049904a43525de9f7a6134d
exposed:              True
exposed-modules:
    Language.Haskell.GHC.ExactPrint
    Language.Haskell.GHC.ExactPrint.Dump
    Language.Haskell.GHC.ExactPrint.ExactPrint
    Language.Haskell.GHC.ExactPrint.Lookup
    Language.Haskell.GHC.ExactPrint.Orphans
    Language.Haskell.GHC.ExactPrint.Parsers
    Language.Haskell.GHC.ExactPrint.Preprocess
    Language.Haskell.GHC.ExactPrint.Transform
    Language.Haskell.GHC.ExactPrint.Types
    Language.Haskell.GHC.ExactPrint.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghc-exactprint-1.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghc-exactprint-1.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghc-exactprint-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-exactprint
hs-libraries:         HSghc-exactprint-1.6.1-71NAdlzl5fm9QnnWAHgUqY
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd directory-1.3.7.1
    filepath-1.4.2.2 free-5.2-FO2Q20euwXcCdGr9UaAYL8 ghc-9.4.8
    ghc-boot-9.4.8 mtl-2.2.2
    ordered-containers-0.2.4-kQGzIFSX2n5kFBthoVzoi
    syb-0.7.3-CiEyKdVdKrBBmPO81uKiz6

haddock-interfaces:
    /usr/share/doc/haskell-ghc-exactprint/html/ghc-exactprint.haddock

haddock-html:         /usr/share/doc/haskell-ghc-exactprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
